@@ -96,11 +96,11 @@ QString AboutDialogPrivate::aboutText() const
             tr("Advanced, easy-to-use, and fast desktop environment based on Qt technologies.",
                "About dialog, 'About' tab text"),
             tr("LXQt would not have been possible without the <a %1>Razor-qt</a> project and its many contributors.",
-               "About dialog, 'About' tab text").arg(QStringLiteral("href=\"https://blog.lxqt.org/2014/11/in-memory-of-razor-qt/\"")),
+               "About dialog, 'About' tab text").arg(QStringLiteral("href=\"https://blog.lxde.org/2014/11/21/in-memory-of-razor-qt/\"")),
             tr("Copyright: © %1-%2 %3", "About dialog, 'About' tab text")
                 .arg(QStringLiteral("2010"), QDate::currentDate().toString(QStringLiteral("yyyy")), QStringLiteral("LXQt team")),
             tr("Homepage: %1", "About dialog, 'About' tab text")
-                .arg(QStringLiteral("<a href=\"https://lxqt.org\">https://lxqt.org</a>")),
+                .arg(QStringLiteral("<a href=\"https://lxqt.github.io\">https://lxqt.github.io</a>")),
             tr("License: %1", "About dialog, 'About' tab text")
                 .arg(QStringLiteral("<a href=\"https://www.gnu.org/licenses/lgpl-2.1.html\">GNU Lesser General Public License version 2.1 or later</a>"
                      " and partly under the "
@@ -114,7 +114,7 @@ QString AboutDialogPrivate::authorsText() const
                 tr("LXQt is developed by the <a %1>LXQt Team and contributors</a>.", "About dialog, 'Authors' tab text")
                     .arg(QStringLiteral(" href=\"https://github.com/lxqt/lxqt\"")),
                 tr("If you are interested in working with our development team, <a %1>join us</a>.", "About dialog, 'Authors' tab text")
-                    .arg(QStringLiteral("href=\"https://lxqt.org\""))
+                    .arg(QStringLiteral("href=\"https://lxqt.github.io\""))
                 );
 }
 
@@ -137,7 +137,8 @@ QString AboutDialogPrivate::translationsText() const
 {
     TranslatorsInfo translatorsInfo;
     return QStringLiteral("%1<p><ul>%2</ul>").arg(
-                tr("LXQt is translated into many languages thanks to the work of the translation teams all over the world.", "About dialog, 'Translations' tab text"),
+                tr("LXQt is translated into many languages thanks to the work of the translation teams all over the world. Translations can be done in <a %1>LXQt-Weblate</a>.", "About dialog, 'Translations' tab text")
+                .arg(QStringLiteral("href=\"https://translate.lxqt-project.org\"")),
                 translatorsInfo.asHtml()
                 );
 }
