@@ -43,7 +43,7 @@ class TranslatorPerson
 public:
 
     TranslatorPerson(const QString &englishName, const QString &nativeName, const QString &contact)
-        :mEnglishName (englishName), mNativeName (nativeName != englishName ? nativeName : ""), mContact (contact)
+        :mEnglishName (englishName), mNativeName (nativeName != englishName ? nativeName : QLatin1String("")), mContact (contact)
     { }
     TranslatorPerson(TranslatorPerson &&other) = default;
 
